from setuptools import setup

setup(name='tf_assist',   #pip install tf_assist
      version='0.1',
      description='The funniest joke in the world',
      url='http://github.com/aniketmaurya/tf_assist',
      author='Aniket Maurya',
      author_email='aniketmaurya.ai@gmail.com',
      license='MIT',
      packages=['assist'],
      zip_safe=False)